{{- define "envVars" -}}
{{ include "externalConfigEnvVars" . }}
{{ include "internalServiceEnvVars" . }}
{{ include "localDevEnvVars" . }}
{{- end -}}

{{- define "externalConfigEnvVars" -}}
- name: SERVICE_GUID
  value: {{ .Values.sguid | quote }}
- name: TABLES_JSON
  value: {{ .Values.tables | toJson | quote }}
- name: "DBS_COUNT"
  value: {{ len .Values.dbs | quote }}
{{- $dbIndex := 0 -}}
{{- range $db := .Values.dbs }}
- name: "DBS_{{ $dbIndex }}_NAME"
  value: {{ $db.name }}
- name: "DBS_{{ $dbIndex }}_TYPE"
  value: {{ $db.type }}
{{- if eq .type "POSTGRES" }}
- name: "DBS_{{ $dbIndex }}_HOST"
  valueFrom:
    configMapKeyRef:
      key: endpoint
      name: {{ include "app-utils.infraNamingPrefix" $db }}-endpoint
- name: "DBS_{{ $dbIndex }}_DB_NAME"
  valueFrom:
    configMapKeyRef:
      key: databaseName
      name: {{ include "app-utils.outputConfigMap" $db }}
- name: "DBS_{{ $dbIndex }}_PASSWORD"
  valueFrom:
    secretKeyRef:
      key: password
      name: {{ include "app-utils.infraNamingPrefix" $db }}-pg-pass
      optional: true
- name: "DBS_{{ $dbIndex }}_USER"
  valueFrom:
    secretKeyRef:
      key: user
      name: {{ include "app-utils.infraNamingPrefix" $db }}-pg-user
      optional: true
# Multi-env Support
- name: "DBS_{{ $dbIndex }}_MULTI_ENV_ENDPOINTS"
  valueFrom:
    configMapKeyRef:
      key: multi_db_json
      name: {{ include "app-utils.infraNamingPrefix" $db }}-endpoint
      optional: true
- name: "DBS_{{ $dbIndex }}_MULTI_ENV_SECRETS"
  valueFrom:
    secretKeyRef:
      name: {{ $db.multiEnvSecretName | default "missing"}}
      key: {{ $db.multiEnvSecretKey | default "missing" }}
      optional: true
{{- else if eq .type "ES" }}
- name: "DBS_{{ $dbIndex }}_HOST"
  valueFrom:
    configMapKeyRef:
      key: endpoint
      name: {{ include "app-utils.infraNamingPrefix" $db }}-endpoint
- name: "DBS_{{ $dbIndex }}_CLUSTER_DOMAIN_NAME"
  valueFrom:
    configMapKeyRef:
      key: clusterDomainName
      name: {{ include "app-utils.outputConfigMap" $db }}
- name: "DBS_{{ $dbIndex }}_PASSWORD"
  valueFrom:
    secretKeyRef:
      key: password
      name: {{ include "app-utils.infraNamingPrefix" $db }}-es-pass
      optional: true
- name: "DBS_{{ $dbIndex }}_USER"
  valueFrom:
    secretKeyRef:
      key: user
      name: {{ include "app-utils.infraNamingPrefix" $db }}-es-user
      optional: true
# Multi-env Support
- name: "DBS_{{ $dbIndex }}_ENDPOINT_URLS_JSON"
  valueFrom:
    configMapKeyRef:
      key: endpointUrlsJson
      name: {{ include "app-utils.infraNamingPrefix" $db }}-endpoint
      optional: true
{{- if not $.Values.global.awsDeployment }}
- name: "DBS_{{ $dbIndex }}_PORT"
  value: "9200"
- name: "DBS_{{ $dbIndex }}_SCHEME"
  value: "http"
{{- end }}
{{- else if (eq .type "OS1") }}
- name: "DBS_{{ $dbIndex }}_HOST"
  valueFrom:
    configMapKeyRef:
      key: endpoint
      name: {{ include "app-utils.infraNamingPrefix" $db }}-endpoint
- name: "DBS_{{ $dbIndex }}_DOMAIN_NAME"
  valueFrom:
    configMapKeyRef:
      key: domainName
      name: {{ include "app-utils.outputConfigMap" $db }}
{{- if $.Values.global.awsDeployment }}
- name: "DBS_{{ $dbIndex }}_PASSWORD"
  valueFrom:
    secretKeyRef:
      key: password
      name: {{ include "app-utils.infraNamingPrefix" $db }}-srch-pass
      optional: true
- name: "DBS_{{ $dbIndex }}_USER"
  valueFrom:
    secretKeyRef:
      key: user
      name: {{ include "app-utils.infraNamingPrefix" $db }}-srch-user
      optional: true
{{- else }}
- name: "DBS_{{ $dbIndex }}_PASSWORD"
  value: "admin"
- name: "DBS_{{ $dbIndex }}_USER"
  value: "admin"
- name: "DBS_{{ $dbIndex }}_PORT"
  value: "9200"
{{- end }}
{{- else if (eq .type "DYNAMODB") }}
- name: "DBS_{{ $dbIndex }}_TABLE_NAME"
  valueFrom:
    configMapKeyRef:
      key: tableName
      name: {{ include "app-utils.outputConfigMap" $db }}
- name: "DBS_{{ $dbIndex }}_AWS_REGION"
  value: {{ $.Values.global.awsRegion | quote }}
{{- if not $.Values.global.awsDeployment }}
- name: "DBS_{{ $dbIndex }}_ENDPOINT_URL"
  value: "http://localstack:4566"
- name: "DBS_{{ $dbIndex }}_USE_LOCALSTACK_CREDS"
  value: "true"
{{- end }}
{{- end }}
{{- $dbIndex = add1 $dbIndex -}}
{{- end }}
{{- end -}}

{{- define "internalServiceEnvVars" -}}
- name: API_PORT
  value: {{ .Values.api.port | quote }}
- name: APP_VERSION
  value: {{ .Chart.Version | quote }}
- name: AWS_REGION
  value: {{ .Values.global.awsRegion | quote }}
- name: CLM_BASE_URL
  value: http://{{ if .Values.clmDomain }}{{ .Values.clmDomain }}{{ else }}{{ include "app-utils.internalIngressHostName" . }}{{ end }}
- name: CLM_CONNECTOR_KEY
  valueFrom:
    secretKeyRef:
      name: org-depro-service-connector
      key: api-key
      optional: true
- name: CLM_CONNECTOR_ID
  valueFrom:
    secretKeyRef:
      name: org-depro-service-connector
      key: connector-id
      optional: true
- name: ENV_NAME
  value: {{ .Values.global.env | quote }}
{{/* Use Postgres cert mounted in app-utils.rds-ca-volume if in AWS */}}
{{- if .Values.global.awsDeployment }}
- name: PGSSLMODE
  value: verify-ca
- name: PGSSLROOTCERT
  value: "/app/certs/rds-combined-ca-bundle.pem"
{{- else }}
- name: PGSSLMODE
  value: disable
{{- end }}
{{- $sqs := (dict "releaseName" .Release.Name "alias" "sqs-depro" ) }}
- name: SQS_QUEUE_NAME
  valueFrom:
    configMapKeyRef:
      key: queueName
      name: {{ include "app-utils.outputConfigMap" $sqs }}
- name: SQS_QUEUE_URL
  valueFrom:
    configMapKeyRef:
      key: URL
      name: {{ include "app-utils.infraNamingPrefix" $sqs }}-arn
{{- end -}}

{{- define "localDevEnvVars" -}}
{{- if not .Values.global.awsDeployment }}
- name: LOGGING_LEVEL
  value: "debug"
- name: LOGGING_MODE
  value: "development"
- name: METRICS_ENABLED
  value: "false"
- name: SQS_AWS_ENDPOINT
  value: "http://localstack:4566"
- name: AWS_ACCESS_KEY_ID
  value: "localstack"
- name: AWS_SECRET_ACCESS_KEY
  value: "localstack"
{{- end }}
{{- end -}}
